@@ -115,12 +115,12 @@ class AnalysisSTEAM:
         # Check if output folder is present. If not, make it.
         if not os.path.isdir(output_path):
             Path(output_path).mkdir(parents=True, exist_ok=True)
-            print('Folder {} did not exist. It was made now.'.format(output_path))
+            if self.verbose: print('Folder {} did not exist. It was made now.'.format(output_path))
 
         # Check if temporary folder is present. If so, delete it.
         if os.path.isdir(temp_path):
             shutil.rmtree(temp_path)
-            print('Folder {} already existed. It was removed.'.format(temp_path))
+            if self.verbose: print('Folder {} already existed. It was removed.'.format(temp_path))
 
     def read_settings(self):
         """
@@ -215,8 +215,9 @@ class AnalysisSTEAM:
     def step_make_model(self, step, verbose: bool = False):
         if verbose:
             print('Making model object named {}'.format(str(step.model_name)))
-        ## Assuming the steam-models directory structure if 'steam-models' found in library path. Else assuming library path directs straight to model
-        if "\steam-models\\" in str(self.library_path) or "/steam-models/" in str(self.library_path):
+        ## Assuming the steam-models directory structure if 'steam-models' or model_library found at the end of library path.
+        # Else assuming library path directs straight to the model
+        if (str(self.library_path).endswith('steam-models')) or (str(self.library_path).endswith('model_library')):
             file_model_data = os.path.join(self.library_path, step.case_model + 's', step.file_model_data, 'input', 'modelData_' + step.file_model_data + '.yaml')
         else:
             file_model_data = os.path.join(self.library_path,'modelData_' + step.file_model_data + '.yaml')
@@ -454,7 +455,7 @@ class AnalysisSTEAM:
                     file_to_copy = os.path.join(self.output_path,                                               csv_file)
                     file_copied  = os.path.join(Path(local_LEDET_folder / simulation_name / 'Input').resolve(), csv_file)
                     shutil.copyfile(file_to_copy, file_copied)
-                    print('Csv file {} copied to {}.'.format(file_to_copy, file_copied))
+                    if verbose: print('Csv file {} copied to {}.'.format(file_to_copy, file_copied))
 
                 # Make magnet field-map folder
                 field_maps_folder = Path(local_LEDET_folder / '..' / 'Field maps' / simulation_name).resolve()
@@ -466,7 +467,7 @@ class AnalysisSTEAM:
                     file_to_copy = os.path.join(self.output_path,  field_map)
                     file_copied  = os.path.join(field_maps_folder, field_map)
                     shutil.copyfile(file_to_copy, file_copied)
-                    print('Field map file {} copied to {}.'.format(file_to_copy, file_copied))
+                    if verbose: ('Field map file {} copied to {}.'.format(file_to_copy, file_copied))
 
             elif 'PSPICE' in software:
                 local_PSPICE_folder = Path(self.settings.local_PSPICE_folder)
@@ -480,7 +481,7 @@ class AnalysisSTEAM:
                     file_to_copy = os.path.join(self.output_path, lib_file)
                     file_copied = os.path.join(local_model_folder, lib_file)
                     shutil.copyfile(file_to_copy, file_copied)
-                    print('Lib file {} copied to {}.'.format(file_to_copy, file_copied))
+                    if verbose: print('Lib file {} copied to {}.'.format(file_to_copy, file_copied))
 
                 # Copy stl files from the output folder
                 list_stl_files = [entry for entry in os.listdir(self.output_path) if (simulation_name in entry) and ('.stl' in entry)]
@@ -488,7 +489,7 @@ class AnalysisSTEAM:
                     file_to_copy = os.path.join(self.output_path,   stl_file)
                     file_copied  = os.path.join(local_model_folder, stl_file)
                     shutil.copyfile(file_to_copy, file_copied)
-                    print('Stl file {} copied to {}.'.format(file_to_copy, file_copied))
+                    if verbose: print('Stl file {} copied to {}.'.format(file_to_copy, file_copied))
 
             else:
                 raise Exception(f'Software {software} not supported for automated folder setup.')
@@ -559,8 +560,8 @@ class AnalysisSTEAM:
             shutil.copyfile(geo_temp, geo_local)
             shutil.copyfile(set_temp, set_local)
 
-        print('Simulation files {} generated.'.format(file_name_temp))
-        print('Simulation files {} copied.'.format(file_name_local))
+        if self.verbose: print('Simulation files {} generated.'.format(file_name_temp))
+        if self.verbose: print('Simulation files {} copied.'.format(file_name_local))
 
     def setup_sim_LEDET(self, simulation_name, sim_number, flag_yaml=True, flag_json=False):
         """
@@ -590,10 +591,10 @@ class AnalysisSTEAM:
             file_name_local  = os.path.join(local_LEDET_folder, simulation_name, 'Input', simulation_name + '_' + str(sim_number) + suffix)
 
             shutil.copyfile(file_name_temp, file_name_output)
-            print('Simulation file {} generated.'.format(file_name_output))
+            if self.verbose: print('Simulation file {} generated.'.format(file_name_output))
 
             shutil.copyfile(file_name_temp, file_name_local)
-            print('Simulation file {} copied.'.format(file_name_local))
+            if self.verbose: print('Simulation file {} copied.'.format(file_name_local))
 
             # os.remove(file_name_temp)
             # print('Temporary file {} deleted.'.format(file_name_temp))
@@ -621,10 +622,10 @@ class AnalysisSTEAM:
         # Copy simulation file
         file_name_temp = os.path.join(output_folder, simulation_name + '.cir')
         file_name_local = os.path.join(local_model_folder, simulation_name + '.cir')
-        print('Simulation file {} generated.'.format(file_name_temp))
+        if self.verbose: print('Simulation file {} generated.'.format(file_name_temp))
 
         shutil.copyfile(file_name_temp, file_name_local)
-        print('Simulation file {} copied.'.format(file_name_local))
+        if self.verbose: print('Simulation file {} copied.'.format(file_name_local))
 
         # os.remove(file_name_temp)
         # print('Temporary file {} deleted.'.format(file_name_temp))
@@ -635,7 +636,7 @@ class AnalysisSTEAM:
             file_to_copy = os.path.join(output_folder, lib_file)
             file_copied = os.path.join(local_model_folder, lib_file)
             shutil.copyfile(file_to_copy, file_copied)
-            print('Lib file {} copied to {}.'.format(file_to_copy, file_copied))
+            if self.verbose: print('Lib file {} copied to {}.'.format(file_to_copy, file_copied))
 
         # Copy stl files from the output folder
         list_stl_files = [entry for entry in os.listdir(output_folder) if (simulation_name in entry) and ('.stl' in entry)]
@@ -643,7 +644,7 @@ class AnalysisSTEAM:
             file_to_copy = os.path.join(output_folder,   stl_file)
             file_copied  = os.path.join(local_model_folder, stl_file)
             shutil.copyfile(file_to_copy, file_copied)
-            print('Stl file {} copied to {}.'.format(file_to_copy, file_copied))
+            if self.verbose: print('Stl file {} copied to {}.'.format(file_to_copy, file_copied))
 
 
     def setup_sim_PyBBQ(self, simulation_name, sim_number):
@@ -667,10 +668,10 @@ class AnalysisSTEAM:
         # Copy simulation file
         file_name_temp = os.path.join(output_folder, simulation_name + '.yaml')
         file_name_local = os.path.join(local_model_folder, simulation_name + '.yaml')
-        print('Simulation file {} generated.'.format(file_name_temp))
+        if self.verbose: print('Simulation file {} generated.'.format(file_name_temp))
 
         shutil.copyfile(file_name_temp, file_name_local)
-        print('Simulation file {} copied.'.format(file_name_local))
+        if self.verbose: print('Simulation file {} copied.'.format(file_name_local))
 
         # os.remove(file_name_temp)
         # print('Temporary file {} deleted.'.format(file_name_temp))
