@@ -80,11 +80,19 @@ class CCT_straight(BaseModel):
     """
         Level 2: Class for straight CCT windings
     """
-    # TODO These variables could be renamed. Current names are as they appear in ProteCCT
-    inner_radius_formers: List[float] = []  # innerRadiusFormers (ProteCCT)
-    former_thickness_underneath_coil: float = None # formerThicknessUnderneathCoil. Thickness of the former underneath the slot holding the strands in [m] (ProteCCT)
-    inner_radius_outer_cylinder: float = None  # innerRadiusOuterCylinder (ProteCCT)
-    thickness_outer_cylinder: float = None # thicknessOuterCylinder (ProteCCT)
+    winding_order: List[int] = None
+    winding_numberTurnsFormers: List[int] = None            # total number of channel turns, ProteCCT: numTurnsPerStrandTotal, FiQuS: n_turnss
+    winding_numRowStrands: List[int] = None                 # number of rows of strands in channel, ProteCCT: numRowStrands, FiQuS: windings_wwns
+    winding_numColumnStrands: List[int] = None              # number of columns of strands in channel, ProteCCT: numColumnStrands, FiQuS: windings_whns
+    winding_chws: List[float] = None                          # width of winding slots, ProteCTT: used to calc. wStrandSlot=winding_chws/numRowStrands, FiQuS: wwws
+    winding_chhs: List[float] = None                          # width of winding slots, ProteCTT: used to calc. wStrandSlot=winding_chhs/numColumnStrands, FiQuS: wwhs
+    former_inner_radiuses: List[float] = []                  # innerRadiusFormers (ProteCCT)
+    former_outer_radiuses: List[float] = []                  # innerRadiusFormers (ProteCCT)
+    former_RRRs: List[float] = []                   # RRRFormer (ProteCCT)
+    #former_thickness_underneath_coil: float = None          # formerThicknessUnderneathCoil. Thickness of the former underneath the slot holding the strands in [m] (ProteCCT)
+    cylinder_inner_radiuses: List[float] = []              # innerRadiusOuterCylinder (ProteCCT)
+    cylinder_outer_radiuses: List[float] = []                  # ProteCCT: thicknessOuterCylinder = cylinder_outer_radiuses - cylinder_inner_radiuses
+    cylinder_RRRs: List[float] = []                         # ProteCCT: RRROuterCylinder
 
 
 class CCT_curved(BaseModel):
@@ -264,28 +272,14 @@ class Threshold(BaseModel):
     DistMax: float = None
 
 
-class Reference(BaseModel):
-    """
-        Level 2: Class for FiQuS Multipole
-    """
-    geometry: str = None
-    mesh: str = None
-    solution: str = None
-
-
 class OptionMultipole(BaseModel):
     """
         Level 2: Class for FiQuS Multipole
     """
-    run_type: str = None  # start_from_geometry, geometry, start_from_mesh, mesh, start_from_solution, solution
-    launch_gui: bool = None
-    reference_files: Reference = Reference()
-    overwrite: bool = None
     with_iron_yoke: bool = None
     compare_to_ROXIE: bool = None
     default_mesh: bool = None
     plot_all: bool = None
-    output_folder: str = None
 
 
 class MeshMultipole(BaseModel):
@@ -331,26 +325,6 @@ class FiQuSMultipole(BaseModel):
 
 
 # CCT
-class Step(BaseModel):
-    """
-        Level 2: Class for FiQuS CCT
-    """
-    run: bool = None
-    gui: bool = None
-
-
-class Steps(BaseModel):
-    """
-        Level 2: Class for FiQuS CCT
-    """
-    clear: bool = None
-    gen_breps: Step = Step()
-    ef_breps: Step = Step()
-    pre_process: Step = Step()
-    mesh: Step = Step()
-    solve: Step = Step()
-    post_process: Step = Step()
-
 
 class Winding_g(BaseModel):  # Geometry related windings _inputs
     """
@@ -358,7 +332,7 @@ class Winding_g(BaseModel):  # Geometry related windings _inputs
     """
     names: List[str] = None  # name to use in gmsh and getdp
     r_wms: List[float] = None  # radius of the middle of the winding
-    n_turnss: List[float] = None  # number of turns
+    #n_turnss: List[float] = None  # number of turns
     ndpts: List[int] = None  # number of divisions of turn, i.e. number of hexagonal elements for each turn
     ndpt_ins: List[int] = None  # number of divisions of terminals in
     ndpt_outs: List[int] = None  # number of divisions of terminals in
@@ -404,10 +378,9 @@ class FQPL_s(BaseModel):  # Solution time used fqpls _inputs (materials and BC)
 
 class Former_g(BaseModel):  # Geometry related formers _inputs
     """
-        Level 2: Class for FiQuS CCT
+        Level 2: Class for FiQuS CCT Options
     """
     names: List[str] = None  # name to use in gmsh and getdp
-    r_ins: List[float] = None  # inner radius
     r_outs: List[float] = None  # outer radius
     z_mins: List[float] = None  # extend of former  in negative z direction
     z_maxs: List[float] = None  # extend of former in positive z direction
@@ -478,11 +451,11 @@ class SolveCCT(BaseModel):
 
 class PostprocCCT(BaseModel):
     """
-        Level 2: Class for FiQuS CCT
+        Level 2: Class for Options FiQuS CCT
     """
-    winding_order: List[int] = None
-    windings_wwns: List[int] = None  # wires in width direction numbers
-    windings_whns: List[int] = None  # wires in height direction numbers
+
+    # windings_wwns: List[int] = None  # wires in width direction numbers
+    # windings_whns: List[int] = None  # wires in height direction numbers
     additional_outputs: List[str] = None  # Name of software specific input files to prepare, like :LEDET3D
     fqpl_export_trim_tol: List[float] = None  # this multiplier times winding extend gives 'z' coordinate above(below) which hexes are exported for LEDET, length of this list must match number of fqpls
     variables: List[str] = None  # Name of variable to post-process by python Gmsh API, like B for magnetic flux density
@@ -498,13 +471,25 @@ class FiQuSCCT(BaseModel):
     mesh: MeshCCT = MeshCCT()
     solve: SolveCCT = SolveCCT()
     postproc: PostprocCCT = PostprocCCT()
-    steps: Steps = Steps()
+
+
+class RunFiQuS(BaseModel):
+    """
+        Class for FiQuS run
+    """
+    type: str = None
+    geometry: str = None
+    mesh: str = None
+    solution: str = None
+    launch_gui: bool = None
+    overwrite: bool = None
 
 
 class FiQuS(BaseModel):
     """
         Level 1: Class for FiQuS options
     """
+    run: RunFiQuS = RunFiQuS()
     cct: FiQuSCCT = FiQuSCCT()
     multipole: FiQuSMultipole = FiQuSMultipole()
 
@@ -749,14 +734,14 @@ class GeometryGenerationOptionsProteCCT(BaseModel):
         Level 2: Class for ProteCCT geometry generation options
     """
     totalConductorLength: float = None
-    numTurnsPerStrandTotal: int = None
+    #numTurnsPerStrandTotal: int = None
     thFormerInsul: float = None
-    wStrandSlot: float = None
-    numRowStrands: int = None
-    numColumnStrands: int = None
+    #wStrandSlot: float = None
+    #numRowStrands: int = None
+    #numColumnStrands: int = None
     IcFactor: float = None
     polyimideToEpoxyRatio: float = None
-    windingOrder: str = None  # Note: it will be written in a single cell in the ProteCCT file
+
 
 
 class PhysicsProteCCT(BaseModel):
@@ -768,8 +753,8 @@ class PhysicsProteCCT(BaseModel):
     BMinAtNominal: float = None
     INominal: float = None
     fieldPeriodicity: float = None
-    RRRFormer: float = None
-    RRROuterCylinder: float = None
+    #RRRFormer: float = None
+    #RRROuterCylinder: float = None
     coolingToHeliumBath: int = None
     fLoopLength: float = None
     addedHeCpFrac: float = None
