@@ -1,8 +1,10 @@
 import os
-import dakota.interfacing as di
 import shutil
+import sys
 from pathlib import Path
 
+from ruamel import yaml
+
 from steam_sdk.builders.BuilderDAKOTA import BuilderDAKOTA
 from steam_sdk.analyses.AnalysisSTEAM import AnalysisSTEAM
 from steam_sdk.data.DataAnalysis import ModifyModel, AddAuxiliaryFile
@@ -11,10 +13,30 @@ class DriverDAKOTA:
 
     def __init__(self, input_DAKOTA_yaml: str):
         self.Builder = BuilderDAKOTA(input_DAKOTA_yaml)
-        self.STEAM_Analysis = AnalysisSTEAM(relative_path_settings='..', input_dictionary=self.Builder.DAKOTA_data.dict(), verbose=True)
+        # self.STEAM_Analysis = AnalysisSTEAM(relative_path_settings='..', input_dictionary=self.Builder.DAKOTA_data.dict(), verbose=True)
         self.variables = self.Builder.DAKOTA_data.DAKOTA_analysis.variables
         self.global_run_counter = 0
 
+        # Define settings file
+        user_name = os.getlogin()
+        name_file_settings = 'settings.' + user_name + '.yaml'
+        path_settings = Path(Path('..') / name_file_settings).resolve()
+        print('user_name:          {}'.format(user_name))
+        print('name_file_settings: {}'.format(name_file_settings))
+        print('path_settings:      {}'.format(path_settings))
+
+        # Read DAKOTA exe path from the settings file
+        with open(path_settings, 'r') as stream:
+            settings_dict = yaml.safe_load(stream)
+        self.path_DAKOTA = settings_dict['DAKOTA_path']
+        print('path_DAKOTA:        {}'.format(self.path_DAKOTA))
+
+        path_dakota_python = os.path.join(self.path_DAKOTA, 'share\dakota\Python')
+        print('path_dakota_python:        {}'.format(path_dakota_python))
+        sys.path.insert(0, path_dakota_python)
+
+        import dakota.interfacing as di
+
 
     def __prepareSteps(self, params):
         counter = 0
@@ -79,7 +101,8 @@ class DriverDAKOTA:
 
 
     def __CalculateOutput_PSPICE(self, outputfile: str):
-        return 1
+        return dict('x1: 12312', 'x2: 12314')
+        # return 1
 
 
     def __CalculateOutput_LEDET(self, outputfile: str):
@@ -123,4 +146,5 @@ class DriverDAKOTA:
             if result_for_dakota[label].asv.function:
                 result_for_dakota[label].function = sim_result[label]
 
+        result_for_dakota.write()
         return 1
