@@ -1,7 +1,5 @@
 import os
 from pathlib import Path
-
-import numpy as np
 import ruamel.yaml
 
 from steam_sdk.builders.BuilderFiQuS import BuilderFiQuS
@@ -14,7 +12,7 @@ class ParserFiQuS:
         Class with methods to read/write FiQuS information from/to other programs
     """
 
-    def __init__(self, builder_FiQuS: BuilderFiQuS = BuilderFiQuS(flag_build=False)):
+    def __init__(self, builder_FiQuS: BuilderFiQuS = None):
         """
             Initialization using a BuilderFiQuS object containing FiQuS parameter structure
         """
@@ -58,11 +56,11 @@ class ParserFiQuS:
             print("Output folder {} does not exist. Making it now".format(output_path))
             Path(output_path).mkdir(parents=True)
 
-        if self.builder_FiQuS.data_FiQuS.general.magnet_type == 'multipole':
+        if self.builder_FiQuS.data_FiQuS.magnet.type == 'multipole':
             dict_to_yaml(self.builder_FiQuS.data_FiQuS.dict(), full_path_file_name + '.yaml', list_exceptions=[])
             dict_to_yaml(self.builder_FiQuS.data_FiQuS_geo.dict(), full_path_file_name + '.geom', list_exceptions=[])
             dict_to_yaml(self.builder_FiQuS.data_FiQuS_set.dict(), full_path_file_name + '.set', list_exceptions=[])
-        elif self.builder_FiQuS.data_FiQuS.general.magnet_type == 'CCT':
+        elif self.builder_FiQuS.data_FiQuS.magnet.type == 'CCT':
             dict_to_yaml(self.builder_FiQuS.data_FiQuS.dict(), full_path_file_name + '.yaml', list_exceptions=[])
         else:
             raise Exception('Incompatible magnet type.')
