@@ -145,10 +145,10 @@ class ParserPSPICE:
                 elif '.AC' in line:
                     self.circuit_data.Analysis.analysis_type = 'frequency'
                     line_split = line.rstrip('\n').split(' ')
-                    self.circuit_data.Analysis.simulation_time.frequency_step = str(line_split[1])
-                    self.circuit_data.Analysis.simulation_time.frequency_points = str(line_split[2])
-                    self.circuit_data.Analysis.simulation_time.frequency_start = str(line_split[3])
-                    self.circuit_data.Analysis.simulation_time.frequency_end = str(line_split[4])
+                    self.circuit_data.Analysis.simulation_frequency.frequency_step = str(line_split[1])
+                    self.circuit_data.Analysis.simulation_frequency.frequency_points = str(line_split[2])
+                    self.circuit_data.Analysis.simulation_frequency.frequency_start = str(line_split[3])
+                    self.circuit_data.Analysis.simulation_frequency.frequency_end = str(line_split[4])
                     continue
                 elif '.STEP' in line:
                     # TODO. Parametric analysis
@@ -318,10 +318,10 @@ class ParserPSPICE:
 
         # Simplify options keys if they have default values
         if self.circuit_data.Options.options_simulation == get_default_options():
-            print('Default simulation options are applied.')
+            if verbose: print('Default simulation options are applied.')
             self.circuit_data.Options.options_simulation = {'all options': 'default'}
         if self.circuit_data.Options.options_autoconverge == get_default_autoconverge_options():
-            print('Default simulation autoconvergence options are applied.')
+            if verbose:  print('Default simulation autoconvergence options are applied.')
             self.circuit_data.Options.options_autoconverge = {'all options': 'default'}
 
         if flag_acquire_auxiliary_files:
@@ -342,6 +342,7 @@ class ParserPSPICE:
 
         return self.circuit_data
 
+
     def _set_all_flags_to_false(self):
         '''
             # Set flags indicating that the last read line corresponds to an item that might span to the next line
@@ -456,7 +457,7 @@ class ParserPSPICE:
                 if name == None or nodes == None or value == None:
                     raise Exception('Netlist component in position #{} is of type {} and requires name, nodes, and value.'.format(s+1, type))
                 if verbose: print('Netlist entry {} in position #{} is treated as a transient-source component.'.format(name, s + 1))
-                rows_netlist.append(add_controlled_source_component(name, nodes, value))
+                rows_netlist.append(add_transient_source_component(name, nodes, value))
             elif type == 'parametrized component':
                 if name == None or nodes == None or value == None:
                     raise Exception('Netlist component in position #{} is of type {} and requires name, nodes, and value.'.format(s+1, type))
@@ -469,7 +470,7 @@ class ParserPSPICE:
         rows_options = []
         options = self.circuit_data.Options.options_simulation
         if options == {'all options': 'default'}:
-            print('Default simulation options are applied.')
+            if verbose: print('Default simulation options are applied.')
             options = get_default_options()
         if options:
             # Add comment and .OPTIONS command before the first entry
@@ -482,7 +483,7 @@ class ParserPSPICE:
         # Prepare options - Autoconverge simulation options
         options_autoconverge = self.circuit_data.Options.options_autoconverge
         if options_autoconverge == {'all options': 'default'}:
-            print('Default autoconverge simulation options_autoconverge are applied.')
+            if verbose: print('Default autoconverge simulation options_autoconverge are applied.')
             options_autoconverge = get_default_autoconverge_options()
         if options_autoconverge:
             # Add comment and .AUTOCONVERGE command before the first entry
@@ -504,11 +505,11 @@ class ParserPSPICE:
             # Check inputs
             if time_start == None:
                 time_start = '0'
-                print('Parameter time_start set to {} by default.'.format(time_start))
+                if verbose: print('Parameter time_start set to {} by default.'.format(time_start))
             if not time_end:
                 raise Exception('When "transient" analysis is selected, parameter Analysis.simulation_time.time_end must be defined.')
             if not min_time_step:
-                print('Parameter min_time_step was missing and it will not be written.')
+                if verbose: print('Parameter min_time_step was missing and it will not be written.')
             # Add analysis entry
             rows_analysis.append(add_transient_analysis(time_start, time_end, min_time_step))
             # If defined, add time schedule (varying minimum time stepping) entry
@@ -516,19 +517,19 @@ class ParserPSPICE:
                 rows_analysis.append(add_transient_time_schedule(time_schedule))
         elif analysis_type == 'frequency':
             # Unpack inputs
-            frequency_step = self.circuit_data.Analysis.simulation_time.frequency_step
-            frequency_points = self.circuit_data.Analysis.simulation_time.frequency_points
-            frequency_start = self.circuit_data.Analysis.simulation_time.frequency_start
-            frequency_end = self.circuit_data.Analysis.simulation_time.frequency_end
+            frequency_step = self.circuit_data.Analysis.simulation_frequency.frequency_step
+            frequency_points = self.circuit_data.Analysis.simulation_frequency.frequency_points
+            frequency_start = self.circuit_data.Analysis.simulation_frequency.frequency_start
+            frequency_end = self.circuit_data.Analysis.simulation_frequency.frequency_end
             # Check inputs
             if frequency_step not in ['DEC','LIN','OCT']:
                 raise Exception('Frequency step in AC analysis has to be one of [DEC,LIN,OCT]')
             if 'Hz' not in frequency_start:
                 frequency_start = str(frequency_start)+'Hz'
-                print('No unit found in AC analysis starting frequency. Added unit Hz')
+                if verbose: print('No unit found in AC analysis starting frequency. Added unit Hz')
             if 'Hz' not in frequency_end:
                 frequency_end = str(frequency_end)+'Hz'
-                print('No unit found in AC analysis last frequency. Added unit Hz')
+                if verbose: print('No unit found in AC analysis last frequency. Added unit Hz')
             if not frequency_step or not frequency_start or not frequency_end or not frequency_points:
                 raise Exception('A parameter for AC analysis is missing.')
             # Add analysis entry
@@ -634,14 +635,14 @@ class ParserPSPICE:
             file_name = ntpath.basename(file_to_copy)
             file_to_write = os.path.join(self.output_path, file_name)
             if os.path.isfile(os.path.join(file_to_copy)):
-                print('File {} exists'.format(file_to_copy))
+                if verbose: print('File {} exists'.format(file_to_copy))
             else:
-                print('File {} does not exist. Skipped.'.format(file_to_copy))
+                if verbose: print('File {} does not exist. Skipped.'.format(file_to_copy))
                 continue
             if os.path.isdir(self.output_path):
-                print('Dir {} exists'.format(self.output_path))
+                if verbose: print('Dir {} exists'.format(self.output_path))
             else:
-                print('Dir {} does not exist. Skipped.'.format(self.output_path))
+                if verbose: print('Dir {} does not exist. Skipped.'.format(self.output_path))
                 continue
             shutil.copyfile(Path(file_to_copy), Path(file_to_write))
 
@@ -754,7 +755,7 @@ def add_transient_analysis(time_start, time_end, min_time_step = None):
 
 def add_AC_analysis(frequency_step, frequency_points, frequency_start, frequency_end):
     ''' Format transient analysis row '''
-    formatted_text = f'.AC {frequency_step} {str(frequency_points)} {str(frequency_start)} {str(frequency_end)}'
+    formatted_text = f'.AC {frequency_step} {str(int(frequency_points))} {str(frequency_start)} {str(frequency_end)}'
     return formatted_text
 
 def add_transient_time_schedule(time_schedule):
