@@ -5,13 +5,15 @@ from steam_sdk.data.DataModelMagnet import DataModelMagnet
 from steam_sdk.parsers.dict_to_yaml import dict_to_yaml
 
 if __name__ == "__main__":
-    path_models = Path.joinpath(Path(__file__).parent.parent.parent, 'C:\\Users\emm\cernbox\SWAN_projects\steam_models\magnets')
-    # path_models = Path.joinpath(Path(__file__).parent.parent.parent, 'tests/builders/model_library/magnets')
+    # path_models = Path.joinpath(Path(__file__).parent.parent.parent, 'C:\\Users\emm\cernbox\SWAN_projects\steam_models\magnets')
+    # path_models = Path.joinpath(Path(__file__).parent.parent.parent, r'E:\Python\steam_models\magnets')
+    path_models = Path.joinpath(Path(__file__).parent.parent.parent, 'tests/builders/model_library/magnets')
     models = [x.parts[-1] for x in Path(path_models).iterdir() if x.is_dir()]
+    #models = ['MCBRD']
 
     for mm in models:
         # Read file
-        file_model_data = Path.joinpath(path_models, mm, 'input', 'modelData_' + mm + '_2.yaml')
+        file_model_data = Path.joinpath(path_models, mm, 'input', 'modelData_' + mm + '.yaml')
         if os.path.isfile(file_model_data):
             # Load yaml keys into DataAnalysis dataclass
             with open(file_model_data, "r") as stream:
